@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.26.3";
+our $VERSION = "v6.27.0";
 
 1;
 __END__
@@ -417,7 +417,7 @@ L<https://rxjs.dev/api/operators/audit>
 
     # 1, 3, 5, 7, 9, ...
     rx_interval(0.7)->pipe(
-        op_audit(sub ($val) { rx_timer(1) }),
+        op_audit(sub ($val) { rx_timer(1) }), # can also use $_ here
     )->subscribe($observer);
 
 =item op_audit_time
@@ -552,7 +552,7 @@ L<https://rxjs.dev/api/operators/debounce>
 
     # 3, complete
     rx_of(1, 2, 3)->pipe(
-        op_debounce(sub ($val) { rx_timer(0.5) }),
+        op_debounce(sub ($val) { rx_timer(0.5) }), # can also use $_ here
     )->subscribe($observer);
 
 =item op_debounce_time
@@ -576,6 +576,12 @@ L<https://rxjs.dev/api/operators/defaultIfEmpty>
         op_default_if_empty(42),
     )->subscribe($observer);
 
+    # 0, 1, complete
+    rx_interval(0.7)->pipe(
+        op_take(2),
+        op_default_if_empty(42),
+    )->subscribe($observer);
+
 =item op_delay
 
 L<https://rxjs.dev/api/operators/delay>
@@ -684,7 +690,7 @@ Works like rxjs's "every", except it emits 1 or 0 instead of true of false.
 
     # 0, complete
     rx_of(5, 10, 15, 18, 20)->pipe(
-        op_every(sub ($value, $idx) { $value % 5 == 0 }),
+        op_every(sub ($value, $idx) { $value % 5 == 0 }), # can also use $_ here
     )->subscribe($observer);
 
 =item op_exhaust_all
@@ -713,11 +719,9 @@ L<https://rxjs.dev/api/operators/exhaustMap>
 
 L<https://rxjs.dev/api/operators/filter>
 
-You can use C<$_> instead of C<$_[0]> inside this operator's callback.
-
     # 0, 2, 4, 6, ... (every 1.4 seconds)
     rx_interval(0.7)->pipe(
-        op_filter(sub {$_[0] % 2 == 0}),
+        op_filter(sub {$_[0] % 2 == 0}), # can also use $_ here
     )->subscribe($observer);
 
     # 0, 2, 4, 6, ... (every 1.4 seconds)
@@ -789,7 +793,7 @@ L<https://rxjs.dev/api/operators/first>
 
     # (pause 7 seconds) 6, complete
     rx_interval(1)->pipe(
-        op_first(sub { $_[0] > 5 }),
+        op_first(sub ($val, $idx) { $val > 5 }), # can also use $_ here
     )->subscribe($observer);
 
     # 0, complete
@@ -1001,7 +1005,7 @@ L<https://rxjs.dev/api/operators/pairwise>
 
     # [0, 1], [1, 2], [2, 3], ...
     rx_interval(1)->pipe(
-        op_pairwise,
+        op_pairwise(),
     )->subscribe(sub {print Dumper($_[0])});
 
 =item op_pluck
@@ -1235,12 +1239,12 @@ L<https://rxjs.dev/api/operators/takeWhile>
 
     # 0, 1, 2, 3, 4, 5, complete
     rx_interval(1)->pipe(
-        op_take_while(sub { $_[0] <= 5 }),
+        op_take_while(sub ($val, $idx) { $val <= 5 }), # can also use $_ here
     )->subscribe($observer);
 
     # 0, 1, 2, 3, 4, 5, 6, complete
     rx_interval(1)->pipe(
-        op_take_while(sub { $_[0] <= 5 }, 1),
+        op_take_while(sub { $_ <= 5 }, 1),
     )->subscribe($observer);
 
 =item op_tap
@@ -1258,7 +1262,7 @@ L<https://rxjs.dev/api/operators/throttle>
 
     # 0, 2, 4, 6, 8, 10, ...
     rx_interval(0.7)->pipe(
-        op_throttle(sub ($val) { rx_timer(1) }),
+        op_throttle(sub ($val) { rx_timer(1) }), # can also use $_ here
     )->subscribe($observer);
 
 =item op_throttle_time
